@@ -1,7 +1,10 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- *   Gnome Apt frontend
+/** -*- Mode: C++; tab-width: 4 -*-
+ * vim: sw=4 ts=4:
  *
- *   Copyright (C) 1998 Havoc Pennington <hp@pobox.com>
+ * Gnome Apt main application class
+ *
+ * 	(C) 1998 Havoc Pennington <hp@pobox.com>
+ * 	    2002, 2003 Filip Van Raemdonck <mechanix@debian.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -17,13 +20,21 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
- */
+ *
+ * 	$Id$
+ *
+ **/
+
 using namespace std;
 
-#include "app.h"
-#include "menus.h"
-#include "gnome-apt.h"
+#include <libgnome/gnome-config.h>
 
+#include "app.h"
+#include "drawtree.h"
+#include "menus.h"
+#include "pkglist.h"
+#include "pkgtree.h"
+#include "gnome-apt.h"
 
 ///// Declarations for non-menu callbacks
 
@@ -36,54 +47,44 @@ static gint delete_event_cb(GtkWidget* w, GdkEvent* event, gpointer data);
 //  this stuff.
 
 static void
-load_geometry(GtkWidget* app, const gchar* override)
-{
-  const gchar* s = 0;
-  gchar* alloced = 0;
-  if (override == 0)
-    {
-      s = alloced = gnome_config_get_string("/gnome-apt/App/geometry");
-    }
-  else 
-    {
-      s = override;
-    }
+load_geometry (GtkWidget* app, const gchar* override) {
+#if 0
+	const gchar* s;
+	gchar* freeable = NULL;
 
-  bool gotset = false;
+	if (!override) {
+/* FIXME */
+		s = freeable = gnome_config_get_string ("/gnome-apt/App/geometry");
+	} else {
+		s = override;
+	}
 
-  if (s != 0)
-    {
-      gint xpos, ypos, width, height;
+	if (s && !gtk_window_parse_geometry (GTK_WINDOW (app), s)) {
+#endif
+		gtk_window_set_default_size (GTK_WINDOW (app), 800, 600);
+#if 0
+	}
 
-      if (gnome_parse_geometry(s, &xpos, &ypos, &width, &height))
-        {
-          gtk_window_set_default_size(GTK_WINDOW(app), width, height);
-          gtk_widget_set_uposition(app, xpos, ypos);
-          gotset = true;
-        }
-      
-      if (alloced) g_free(alloced);
-    }
-
-  if (gotset == false)
-    {
-      gtk_window_set_default_size(GTK_WINDOW(app), 400, 500);
-    }
+	g_free (freeable);
+#endif
 }
 
 static void
-save_geometry(GtkWidget* app)
-{
-  if (!GTK_WIDGET_REALIZED(app)) return; // no window on screen
+save_geometry (GtkWidget* app) {
+	gchar* s;
+	gint x, y, w, h;
 
-  gchar* s = gnome_geometry_string(app->window);
+	if (!GTK_WIDGET_REALIZED (app))
+		return; // no window on screen
 
-  if (s)
-    {
-      gnome_config_set_string("/gnome-apt/App/geometry", s);
-      gnome_config_sync();
-      g_free(s);
-    }
+	gdk_window_get_geometry (app->window, &x, &y, &w, &h, NULL);
+
+	if ((s = g_strdup_printf ("%dx%d%+d%+d", w, h, x, y))) {
+/* FIXME */
+		gnome_config_set_string ("/gnome-apt/App/geometry", s);
+		gnome_config_sync ();
+		g_free (s);
+	}
 }
 
 
@@ -101,6 +102,11 @@ GAptApp::GAptApp(const gchar* geometry)
   init(geometry);
 }
 
+static void
+status_changed_cb (GAptObject* obj, gchar* s, GAptApp* app) {
+	app->set_status (s);
+}
+
 void
 GAptApp::init(const gchar* geometry)
 {
@@ -117,39 +123,29 @@ GAptApp::init(const gchar* geometry)
   gnome_app_set_statusbar(GNOME_APP(app_),
                           appbar_);
 
-  pkgtree_ = new GAptPkgTree;
-  pkglist_ = new GAptPkgList(pkgtree_, GNOME_APPBAR(appbar_));
+	app_treeview = new DrawTree (new GAptPkgTree);
+	GAptPkgTree* pkgtree = app_treeview->getModel();
+	pkglist_ = new GAptPkgList (app_treeview, GNOME_APPBAR (appbar_));
 
   gnome_app_set_contents(GNOME_APP(app_), pkglist_->widget());
 
-  gtk_signal_connect(GTK_OBJECT(app_),
-                     "delete_event",
-                     GTK_SIGNAL_FUNC(delete_event_cb),
-                     this);
-
-  gtk_signal_connect(GTK_OBJECT(app_),
-                     "key_press_event",
-                     GTK_SIGNAL_FUNC(keypress_cb),
-                     this);
-
-  pkgtree_->set_status(this);
+	g_signal_connect (G_OBJECT (app_), "delete_event", G_CALLBACK (delete_event_cb), this);
+	g_signal_connect (G_OBJECT (app_), "key_press_event", G_CALLBACK (keypress_cb), this);
+	g_signal_connect (G_OBJECT (pkgtree->gaptObject()),
+	      "status_changed", G_CALLBACK (status_changed_cb), this);
 
   progress_ = new Progress(appbar_);
 
   // do this last so it reflects the final state.
   gnome_apt_create_main_menu(GNOME_APP(app_), GNOME_APPBAR(appbar_), pkglist_);
 
-  set_selection(0); // get all initial state set up
-
   gtk_widget_show (app_);
 }
 
-GAptApp::~GAptApp()
-{
-  // Order is very important here, since some of these things
-  //  hold references to others.
-  delete pkgtree_; // Deletes the DrawTree for us.
-  pkgtree_ = 0;
+GAptApp::~GAptApp (void) {
+	delete app_treeview->getModel();
+	delete app_treeview;
+	app_treeview = 0;
   delete pkglist_;
   pkglist_ = 0;
   delete progress_;
@@ -163,13 +159,6 @@ GAptApp::~GAptApp()
     }
 }
 
-void
-GAptApp::set_selection(pkgCache::Package* p)
-{
-  pkglist_->set_selection(p);
-  gnome_apt_menus_selection_changed(pkglist_);
-}
-
 //////////////////////////////////////////////
 // General callbacks
 
@@ -193,18 +182,21 @@ GAptApp::keypress_cb(GtkWidget* w, GdkEventKey* event, gpointer data)
 gint
 GAptApp::key(GdkEventKey* event)
 {
-  if (pkgtree_)
-    {
-      DrawTree* dt = pkgtree_->tree();
-      if (dt)
-        {
-          bool handled = dt->consider_key_event(event);
+	if (GTK_IS_ENTRY (GTK_WINDOW (widget())->focus_widget)) {
+		ga_debug ("focus_widget is entry: %s",
+		      G_OBJECT_TYPE_NAME (GTK_WINDOW (widget())->focus_widget));
+		return FALSE;
+	} else {
+		ga_debug ("focus_widget type: %s",
+		      G_OBJECT_TYPE_NAME (GTK_WINDOW (widget())->focus_widget));
+	}
+
+	if (app_treeview) {
+		bool handled = app_treeview->consider_key_event (event);
           if (handled)
-            gtk_signal_emit_stop_by_name(GTK_OBJECT(app_), "key_press_event");
-          
+				g_signal_stop_emission_by_name (G_OBJECT (app_), "key_press_event");
           return handled;
-        }
-    }
+	}
 
   return FALSE;
 }
@@ -222,7 +214,7 @@ GAptApp::Progress::Update()
       gnome_appbar_set_status(GNOME_APPBAR(appbar_), Op.c_str());
     }
   
-  gnome_appbar_set_progress(GNOME_APPBAR(appbar_), Percent/100.0);
+	gnome_appbar_set_progress_percentage (GNOME_APPBAR (appbar_), Percent/100.0);
   
   // flush
   while (gtk_events_pending())
@@ -234,7 +226,7 @@ void
 GAptApp::Progress::Done()
 {
   gnome_appbar_refresh(GNOME_APPBAR(appbar_));
-  gnome_appbar_set_progress(GNOME_APPBAR(appbar_), 0.0);
+	gnome_appbar_set_progress_percentage (GNOME_APPBAR (appbar_), 0.0);
 }
 
 GAptApp::Progress::Progress(GtkWidget* appbar)
