@@ -1,7 +1,10 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- *   Gnome Apt frontend
+/** -*- Mode: C++; tab-width: 4 -*-
+ * vim: sw=4 ts=4:
  *
- *   Copyright (C) 1998 Havoc Pennington <hp@pobox.com>
+ * Gnome Apt package cache handling class
+ *
+ * 	(C) 1998 Havoc Pennington <hp@pobox.com>
+ * 	    2003, 2004 Filip Van Raemdonck <mechanix@debian.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -17,78 +20,80 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
- */
+ *
+ * 	$Id$
+ *
+ **/
 
 #ifndef GNOME_APT_CACHE_H
 #define GNOME_APT_CACHE_H
 
-#include <gnome-apt.h>
-
-#include <apt-pkg/error.h>
-#include <apt-pkg/cmndline.h>
-#include <apt-pkg/init.h>
 #include <apt-pkg/depcache.h>
-#include <apt-pkg/sourcelist.h>
-#include <apt-pkg/pkgcachegen.h>
-#include <apt-pkg/algorithms.h>
-#include <apt-pkg/pkgsystem.h>
 #include <apt-pkg/pkgrecords.h>
-
 #include <set>
 
 using namespace std;
 
-// This is useless now, it's here so we can easily add features.
+class pkgPolicy;
+class GAProgress;
+
 class GAptCache : public pkgDepCache {
 public:
-  GAptCache(pkgCache *Cache);
+	GAptCache (pkgCache*, pkgPolicy*);
+	~GAptCache (void);
+
+	struct aptitude_state {
+		bool new_package;
+		pkgCache::State::PkgSelectedState selection_state;
+	};
+
+	void forget_new (void);
+	void set_states (set<string>&);
+
+	inline void mark_new (const PkgIterator& Pkg, bool newstate = false) {
+		package_states[Pkg->ID].new_package = newstate;
+	}
+
+	/* Ideally, this would be dependent on the cache type. */
+	typedef enum {
+		StatusNowBroken,
+		StatusNewInstall, StatusUpgrade, StatusDowngrade, StatusDelete, StatusInstall,
+		StatusNotInstalled,
+		StatusKept, StatusHeld,
+		StatusOutdated, StatusUptodate,
+		StatusTypeEnd
+	} PkgStatusType;
+
+	PkgStatusType pkgStatus (pkgCache::PkgIterator&);
+	static const char* statusText (PkgStatusType);
+
+	const char* priorityString (pkgCache::PkgIterator&, pkgCache::State::VerPriority*);
+	pkgRecords::Parser* GAptCache::pkgParser (pkgCache::PkgIterator&);
 
 private:
-
+	aptitude_state* package_states;
+	pkgRecords* records;
 };
 
-
 class GAptCacheFile
 {  
   FileFd *file_;
   MMap *map_;
-  GAptCache *cache_;
-  pkgRecords* records_;
+	GAptCache* cache_;
 
 public:
-  GAptCache* cache() { return cache_; }
-  pkgRecords* records() { return records_; }
-
-
-#if 0  
-  inline operator GAptCache &() {return *cache_;};
-  inline GAptCache *operator ->() {return cache_;};
-  inline GAptCache &operator *() {return *cache_;};
-#endif  
-
-  bool Open();
-
-  // An update run (like apt-get update)
-  bool UpdateAndReopen();
-
-  // A whole Install run (install whatever is selected)
-  bool Install();
+	GAptCache* cache() { return cache_; }
 
+	bool Open (OpProgress*);
   // Mark packages that can be upgraded without removals
   //  or installs (apt-get upgrade)
   void MarkUpgrades();
 
-  // apt-get dist-upgrade - Mark packages, allowing removals/installs
-  void SmartMarkUpgrades();
-
   // Fix broken packages
   void Fix();
 
-  GAptCacheFile() : file_(0), map_(0), cache_(0), records_(0) {};
-  ~GAptCacheFile()
-    {
-      clear();
-    }   
+	GAptCacheFile (void) : file_ (0), map_ (0), cache_ (0) {}
+	~GAptCacheFile (void) { clear(); }
 
   class CacheView {
   public:
@@ -114,22 +119,13 @@ public:
     v->set_cache(0);
   }
 
-  const vector<string> & sections() { return sections_; }
-
 private:
-  
-  set<CacheView*> views_;
+	set<CacheView*> views_;
+	set<string> pkg_names;
 
-  void clear();
-
-  vector<string> sections_;
+	void clear (bool = false);
 };
 
-// Return our cache file, or 0 if the cache file is not created
-//  or was not created successfully.
-GAptCacheFile* gnome_apt_cache_file     (void);
-
-void       gnome_apt_cache_file_init    ();
-void       gnome_apt_cache_file_shutdown();
+GAptCacheFile* gnome_apt_cache_file_init (OpProgress*);
 
 #endif
