@@ -1,7 +1,10 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- *   Gnome Apt frontend
+/** -*- Mode: C++; tab-width: 4 -*-
+ * vim: sw=4 ts=4:
  *
- *   Copyright (C) 1998 Havoc Pennington <hp@pobox.com>
+ * Gnome Apt filter manipulation bar
+ *
+ * 	(C) 1998 Havoc Pennington <hp@pobox.com>
+ * 	    2003, 2004 Filip Van Raemdonck <mechanix@debian.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -17,29 +20,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
- */
+ *
+ * 	$Id$
+ *
+ **/
+
 using namespace std;
 
 #include "filterbar.h"
-#include "tooltips.h"
-
-static GtkWidget* 
-arrow_item(const char* name)
-{
-  GtkWidget* item       = gtk_menu_item_new();
-  GtkWidget* hbox       = gtk_hbox_new(FALSE, 5);
-  GtkWidget* arrow      = gtk_arrow_new(GTK_ARROW_DOWN, GTK_SHADOW_OUT);
-  GtkWidget* label      = gtk_label_new(name);
-  
-  gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
-  gtk_box_pack_start(GTK_BOX(hbox), arrow, TRUE, TRUE, 0);
-
-  gtk_container_add (GTK_CONTAINER(item), hbox);
-
-  gtk_widget_show_all(item);
-
-  return item;
-}
+#include "gtkexpander.h"
+#include "search.h"
 
 GAptFilterBar::GAptFilterBar(Filter* filter)
   : filter_(filter), changing_state_(false)
@@ -48,111 +38,76 @@ GAptFilterBar::GAptFilterBar(Filter* filter)
 
   filter_->add_view(this);
 
-  bar_ = gtk_menu_bar_new();
+	bar_ = gtk_expander_new (_("Filter Listed Packages"), _("Filter Listed Packages"), 0);
 
-  // Filters
+	GtkWidget* hbox = gtk_hbox_new (FALSE, 0);
+	gtk_container_add (GTK_CONTAINER (bar_), hbox);
 
-  GtkWidget* filters      = gtk_menu_item_new_with_label(_("Filters:             "));
+	GtkWidget* tbl = gtk_table_new (2, 2, FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (tbl), GAPT_PAD_BIG);
+	gtk_table_set_row_spacings (GTK_TABLE (tbl), 0);
+	gtk_table_set_col_spacings (GTK_TABLE (tbl), GAPT_PAD_BIG);
+	gtk_box_pack_start (GTK_BOX (hbox), tbl, FALSE, FALSE, 0);
 
-  gtk_menu_bar_append(GTK_MENU_BAR(bar_), filters);
+	GtkWidget* lbl = gtk_label_new (_("Status Filter"));
+	gtk_label_set_justify (GTK_LABEL (lbl), GTK_JUSTIFY_LEFT);
+	gtk_table_attach (GTK_TABLE (tbl), lbl, 0, 2, 0, 1, GTK_FILL, (GtkAttachOptions) 0, 0, 0);
+	gtk_misc_set_alignment (GTK_MISC (lbl), 0, 0.5);
 
-  GtkWidget* menu       = gtk_menu_new();
+	GtkWidget* vbox = gtk_vbox_new (FALSE, 0);
+	gtk_table_attach (GTK_TABLE (tbl), vbox, 1, 2, 1, 2, GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 
-  gtk_menu_item_set_submenu(GTK_MENU_ITEM(filters), menu);
+/*	GtkWidget* item = gtk_check_button_new_with_label (_("All statuses"));
+	gtk_box_pack_start (GTK_BOX (vbox), item, TRUE, TRUE, 0);
+	g_signal_connect (G_OBJECT (item), "toggled", G_CALLBACK (::status_clear), this);
 
   GtkWidget* item       = gtk_menu_item_new_with_label(_("Clear all"));
-
-  gtk_menu_append(GTK_MENU(menu), item);
-
-  gtk_signal_connect(GTK_OBJECT(item), "activate",
-                     GTK_SIGNAL_FUNC(::all_clear),
-                     this);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (::all_clear), this);
 
   item                  = gtk_menu_item_new_with_label(_("Reverse all"));
-
-  gtk_menu_append(GTK_MENU(menu), item);
-
-  gtk_signal_connect(GTK_OBJECT(item), "activate",
-                     GTK_SIGNAL_FUNC(::all_reverse),
-                     this);
-
-  // Status
-
-  item       = arrow_item(_("Status"));
-  menu       = gtk_menu_new();  
-
-  gtk_menu_set_title(GTK_MENU(menu), _("Status Filter"));
-
-  gtk_menu_item_set_submenu(GTK_MENU_ITEM(item), menu);
-  gtk_menu_bar_append(GTK_MENU_BAR(bar_), item);
-
-  item = gtk_tearoff_menu_item_new();
-  gtk_menu_append(GTK_MENU(menu), item);
-
-  item = gtk_menu_item_new_with_label(_("Clear"));
-  gtk_menu_append(GTK_MENU(menu), item);
-
-  gtk_signal_connect(GTK_OBJECT(item), "activate",
-                     GTK_SIGNAL_FUNC(::status_clear),
-                     this);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (::all_reverse), this);
 
   item = gtk_menu_item_new_with_label(_("Reverse"));
-  gtk_menu_append(GTK_MENU(menu), item);
-
-  gtk_signal_connect(GTK_OBJECT(item), "activate",
-                     GTK_SIGNAL_FUNC(::status_reverse),
-                     this);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (::status_reverse), this);*/
 
   int i = 0;
-  while (i < Util::StatusTypeEnd)
-    {
-      Util::StatusType status = static_cast<Util::StatusType>(i);
-      const char* s = Util::status_string(status);
-      GtkWidget* mi = gtk_check_menu_item_new_with_label(s);
-      // why you'd ever not do this is beyond me
-      gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (mi), TRUE);
-      gtk_check_menu_item_set_state       (GTK_CHECK_MENU_ITEM (mi), 
-                                           filter_->get_status_filter(status));
+	while (i < GAptCache::StatusTypeEnd) {
+		GAptCache::PkgStatusType status = static_cast<GAptCache::PkgStatusType> (i);
+		const char* s = GAptCache::statusText (status);
+		GtkWidget* mi = gtk_check_button_new_with_label (s);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (mi), filter_->get_status_filter (status));
 
       statuses_[mi] = status;
-
-      gtk_signal_connect(GTK_OBJECT(mi), "toggled",
-                         GTK_SIGNAL_FUNC(::status_toggled),
-                         this);
-
-      gtk_menu_append(GTK_MENU(menu), mi);
-
-      //gtk_widget_show(mi);
+		gtk_box_pack_start (GTK_BOX (vbox), mi, TRUE, TRUE, 0);
+		g_signal_connect (G_OBJECT (mi), "toggled", G_CALLBACK (::status_toggled), this);
 
       ++i;
     }
 
-  // Priority
+	tbl = gtk_table_new (2, 2, FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (tbl), GAPT_PAD_BIG);
+	gtk_table_set_row_spacings (GTK_TABLE (tbl), 0);
+	gtk_table_set_col_spacings (GTK_TABLE (tbl), GAPT_PAD_BIG);
+	gtk_box_pack_start (GTK_BOX (hbox), tbl, FALSE, FALSE, 0);
 
-  item       = arrow_item(_("Priority"));
-  menu       = gtk_menu_new();  
+	lbl = gtk_label_new (_("Priority Filter"));
+	gtk_label_set_justify (GTK_LABEL (lbl), GTK_JUSTIFY_LEFT);
+	gtk_table_attach (GTK_TABLE (tbl), lbl, 0, 2, 0, 1, GTK_FILL, (GtkAttachOptions) 0, 0, 0);
+	gtk_misc_set_alignment (GTK_MISC (lbl), 0, 0.5);
 
-  gtk_menu_set_title(GTK_MENU(menu), _("Priority Filter"));
+	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_table_attach (GTK_TABLE (tbl), vbox, 1, 2, 1, 2, GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 
-  gtk_menu_item_set_submenu(GTK_MENU_ITEM(item), menu);
-  gtk_menu_bar_append(GTK_MENU_BAR(bar_), item);
-
-  item = gtk_tearoff_menu_item_new();
-  gtk_menu_append(GTK_MENU(menu), item);
-
-  item = gtk_menu_item_new_with_label(_("Clear"));
-  gtk_menu_append(GTK_MENU(menu), item);
-
-  gtk_signal_connect(GTK_OBJECT(item), "activate",
-                     GTK_SIGNAL_FUNC(::priority_clear),
-                     this);
+/*	item = gtk_menu_item_new_with_label (_("All"));
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (::priority_clear), this);
 
   item = gtk_menu_item_new_with_label(_("Reverse"));
-  gtk_menu_append(GTK_MENU(menu), item);
-
-  gtk_signal_connect(GTK_OBJECT(item), "activate",
-                     GTK_SIGNAL_FUNC(::priority_reverse),
-                     this);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (::priority_reverse), this);*/
 
   // don't want to depend on int mapping for this,
   //  since it's outside my control
@@ -182,29 +137,26 @@ GAptFilterBar::GAptFilterBar(Filter* filter)
       pkgCache::State::VerPriority priority = iter_array[i];
 
       const char* s = pri_names[i];
-      GtkWidget* mi = gtk_check_menu_item_new_with_label(s);
-      // why you'd ever not do this is beyond me
-      gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (mi), TRUE);
-      gtk_check_menu_item_set_state       (GTK_CHECK_MENU_ITEM (mi), 
-                                           filter_->get_priority_filter(priority));
+		GtkWidget* mi = gtk_check_button_new_with_label (s);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (mi), filter_->get_priority_filter (priority));
 
       priorities_[mi] = priority;
-
-      gtk_signal_connect(GTK_OBJECT(mi), "toggled",
-                         GTK_SIGNAL_FUNC(::priority_toggled),
-                         this);
-
-      gtk_menu_append(GTK_MENU(menu), mi);
-
-      //gtk_widget_show(mi);
+		gtk_box_pack_start (GTK_BOX (vbox), mi, TRUE, TRUE, 0);
+		g_signal_connect (G_OBJECT (mi), "toggled", G_CALLBACK (::priority_toggled), this);
 
       ++i;
     }
+
+	GtkWidget* w = gapt_search_new (gnome_apt_cache_file());
+	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
+	filter_->set_search_filter (GAPT_SEARCH (w));
+
+	gtk_expander_set_expanded (GTK_EXPANDER (bar_), TRUE);
 }
 
-GAptFilterBar::~GAptFilterBar()
-{
-  filter_->remove_view(this);
+GAptFilterBar::~GAptFilterBar (void) {
+	filter_->remove_view (this);
+	delete filter_;
 }
 
 void
@@ -214,21 +166,17 @@ GAptFilterBar::filter_changed()
 
   changing_state_ = true;
 
-  map<GtkWidget*,Util::StatusType>::iterator i = statuses_.begin();
-  while (i != statuses_.end()) 
-    {
-      gtk_check_menu_item_set_state(GTK_CHECK_MENU_ITEM(i->first),
-                                    filter_->get_status_filter(i->second));
-
+	map<GtkWidget*, GAptCache::PkgStatusType>::iterator i = statuses_.begin();
+	while (i != statuses_.end()) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (i->first),
+		      filter_->get_status_filter (i->second));
       ++i;
     }
 
   map<GtkWidget*,pkgCache::State::VerPriority>::iterator j = priorities_.begin();
-  while (j != priorities_.end())
-    {
-      gtk_check_menu_item_set_state(GTK_CHECK_MENU_ITEM(j->first),
-                                    filter_->get_priority_filter(j->second));
-
+	while (j != priorities_.end()) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (j->first),
+		      filter_->get_priority_filter (j->second));
       ++j;
     }
 
@@ -307,14 +255,12 @@ GAptFilterBar::status_toggled(GtkWidget* w)
 {
   if (changing_state_) return;
 
-  map<GtkWidget*,Util::StatusType>::const_iterator i = statuses_.find(w);
-  g_return_if_fail (i != statuses_.end());
-
-  Util::StatusType status = i->second;
+	map<GtkWidget*, GAptCache::PkgStatusType>::const_iterator i = statuses_.find (w);
+	g_return_if_fail (i != statuses_.end());
+	GAptCache::PkgStatusType status = i->second;
 
   changing_state_ = true;
-  filter_->set_status_filter(status, 
-                             GTK_CHECK_MENU_ITEM(w)->active);
+	filter_->set_status_filter (status, GTK_TOGGLE_BUTTON (w)->active);
   changing_state_ = false;
 }
 
@@ -330,8 +276,7 @@ GAptFilterBar::priority_toggled(GtkWidget* w)
   pkgCache::State::VerPriority priority = i->second;
   
   changing_state_ = true;
-  filter_->set_priority_filter(priority, 
-                               GTK_CHECK_MENU_ITEM(w)->active);
+	filter_->set_priority_filter (priority, GTK_TOGGLE_BUTTON (w)->active);
   changing_state_ = false;
 }
 
